@@ -30,10 +30,10 @@ int           screen_inited = 0;
 
 ScreenPrinter* sp;
 
-#ifdef RTP_STREAM
-double last_rtpstream_rate_out = 0;
-double last_rtpstream_rate_in = 0;
-#endif
+double last_artpstream_rate_out = 0;
+double last_vrtpstream_rate_out = 0;
+double last_artpstream_rate_in = 0;
+double last_vrtpstream_rate_in = 0;
 
 /* ERR is actually -1, but this prevents us from needing to use curses.h in
  * sipp.cpp. */
@@ -261,7 +261,6 @@ void ScreenPrinter::get_lines()
 }
 
 bool do_hide = true;
-bool show_index = false;
 
 void ScreenPrinter::draw_scenario_screen()
 {
@@ -269,7 +268,6 @@ void ScreenPrinter::draw_scenario_screen()
     char buf[bufsiz];
     char left_buf[40];
     char right_buf[bufsiz];
-    int divisor;
     extern int pollnfds;
 
     unsigned long long total_calls =
@@ -287,7 +285,7 @@ void ScreenPrinter::draw_scenario_screen()
             lines.push_back("  Users (length)   Port   Total-time  "
                             "Total-calls  Remote-host");
             snprintf(buf, bufsiz,
-                     "  %d (%d ms)   %-5d %6lu.%02lu s     %8llu  %s:%d(%s)",
+                     "  %d (%d ms)   %-5d %6lu.%02lu s     %8llu  %.20s:%d(%s)",
                      users, duration, local_port, clock_tick / 1000,
                      (clock_tick % 1000) / 10, total_calls, remote_ip,
                      remote_port, TRANSPORT_TO_STRING(transport));
@@ -297,7 +295,7 @@ void ScreenPrinter::draw_scenario_screen()
                             "Total-calls  Remote-host");
             snprintf(
                 buf, bufsiz,
-                "  %3.1f(%d ms)/%5.3fs   %-5d %6lu.%02lu s     %8llu  %s:%d(%s)",
+                "  %3.1f(%d ms)/%5.3fs   %-5d %6lu.%02lu s     %8llu  %.20s:%d(%s)",
                 rate, duration, (double)rate_period_ms / 1000.0, local_port,
                 clock_tick / 1000, (clock_tick % 1000) / 10, total_calls,
                 remote_ip, remote_port, TRANSPORT_TO_STRING(transport));
@@ -321,7 +319,7 @@ void ScreenPrinter::draw_scenario_screen()
     }
     snprintf(right_buf, 40, "%lu ms scheduler resolution",
              ms_since_last_tick / std::max(scheduling_loops, 1ul));
-    snprintf(buf, bufsiz, "  %-38s  %-37s", left_buf, right_buf);
+    snprintf(buf, bufsiz, "  %-38.38s  %-37.37s", left_buf, right_buf);
     lines.push_back(buf);
 
     /* 2nd line */
@@ -362,6 +360,12 @@ void ScreenPrinter::draw_scenario_screen()
         lines.push_back(buf);
     }
 
+    if (auto_answer) {
+        snprintf(buf, 80, "  %llu requests auto-answered",
+                 display_scenario->stats->GetStat(CStat::CPT_G_C_AutoAnswered));
+        lines.push_back(buf);
+    }
+
     /* 4th line , sockets and optional errors */
     snprintf(left_buf, 40, "%d open sockets", pollnfds);
     snprintf(buf, bufsiz, "  %-38s  %lu/%lu/%lu %s errors (send/recv/cong)",
@@ -385,43 +389,48 @@ void ScreenPrinter::draw_scenario_screen()
         lines.push_back(buf);
     }
 #endif
-#ifdef RTP_STREAM
     /* if we have rtp stream thread running */
     if (rtpstream_numthreads) {
-        unsigned long tempbytes;
-        unsigned long last_tick = clock_tick;
-        /* Saved clock_tick to last_tick and use that in calcs since clock tick */
-        /* can change during calculations.                                      */
+        unsigned long TempABytes;
+        unsigned long TempVBytes;
         if (ms_since_last_tick) {
-            tempbytes = rtpstream_bytes_out;
+            TempABytes= rtpstream_abytes_out;
+            TempVBytes= rtpstream_vbytes_out;
             /* Calculate integer and fraction parts of rtp bandwidth; this value
              * will be saved and reused in the case where last_tick==last_report_time
              */
-            last_rtpstream_rate_out = ((double)tempbytes) / ms_since_last_tick;
+            last_artpstream_rate_out= ((double)TempABytes)/ ms_since_last_tick;
+            last_vrtpstream_rate_out= ((double)TempVBytes)/ ms_since_last_tick;
             /* Potential race condition betwen multiple threads updating the
-             * rtpstream_bytes value. We subtract the saved tempbytes value
+             * rtpstream_bytes value. We subtract the saved TempBytes value
              * rather than setting it to zero to minimise the chances of missing
              * an update to rtpstream_bytes [update between printing stats and
              * zeroing the counter]. Ideally we would atomically subtract
-             * tempbytes from rtpstream_bytes.
+             * TempBytes from rtpstream_bytes.
              */
-            rtpstream_bytes_out -= tempbytes;
-            tempbytes = rtpstream_bytes_in;
-            last_rtpstream_rate_in = ((double)tempbytes) / ms_since_last_tick;
-            rtpstream_bytes_in -= tempbytes;
+            rtpstream_abytes_out -= TempABytes;
+            rtpstream_vbytes_out -= TempVBytes;
+            TempABytes= rtpstream_abytes_in;
+            TempVBytes= rtpstream_vbytes_in;
+            last_artpstream_rate_in= ((double)TempABytes)/ ms_since_last_tick;
+            last_vrtpstream_rate_in= ((double)TempVBytes)/ ms_since_last_tick;
+            rtpstream_abytes_in -= TempABytes;
+            rtpstream_vbytes_in -= TempVBytes;
         }
 
-        snprintf(left_buf, 40, "%lu Total RTP pckts sent", rtpstream_pckts);
-        snprintf(buf, bufsiz,"  %-38s  %.3f kB/s RTP OUT",
-                left_buf, last_rtpstream_rate_out);
+        snprintf(left_buf, 40, "%lu Total AUDIO RTP pckts sent", rtpstream_apckts);
+        snprintf(buf, bufsiz, "  %-38s  %.3f kB/s AUDIO RTP OUT", left_buf, last_artpstream_rate_out);
+        lines.push_back(buf);
+        snprintf(left_buf, 40, "%lu Total VIDEO RTP pckts sent", rtpstream_vpckts);
+        snprintf(buf, bufsiz, "  %-38s  %.3f KB/s VIDEO RTP OUT", left_buf, last_vrtpstream_rate_out);
         lines.push_back(buf);
 
         snprintf(left_buf, 40, "%lu RTP sending threads active", rtpstream_numthreads);
-        snprintf(buf, bufsiz, "  %-38s  %.3f kB/s RTP IN",
-                 left_buf, last_rtpstream_rate_in);
+        snprintf(buf, bufsiz, "  %-38s  %.3f kB/s AUDIO RTP IN", left_buf, last_artpstream_rate_in);
+        lines.push_back(buf);
+        snprintf(buf, bufsiz, "  %-38s  %.3f KB/s VIDEO RTP IN", left_buf, last_vrtpstream_rate_in);
         lines.push_back(buf);
     }
-#endif
 
     /* 5th line, RTP echo statistics */
     if (rtp_echo_enabled && media_socket_audio > 0) {
@@ -471,9 +480,6 @@ void ScreenPrinter::draw_scenario_screen()
             continue;
         }
         int buf_len = 0;
-        if (show_index) {
-            buf_len += snprintf(buf + buf_len, bufsiz - buf_len, "%-2lu:", index);
-        }
 
         if (SendingMessage* src = curmsg->send_scheme) {
             if (creationMode == MODE_SERVER) {
@@ -628,11 +634,16 @@ void ScreenPrinter::draw_scenario_screen()
                      curmsg->M_nbCmdSent,
                      "",
                      "");
+        } else if (curmsg->M_type == MSG_TYPE_RECV) {
+            WARNING("<recv> without request/response?");
+            snprintf(buf, bufsiz, "            [ recv? ]              ");
         } else {
-            ERROR("Scenario command not implemented in display");
+            ERROR("Scenario command %d not implemented in display", curmsg->M_type);
         }
 
-        lines.push_back(buf);
+        char buf_with_index[80] = {0};
+        snprintf(buf_with_index, 80, "%-2lu:%s", index, buf);
+        lines.push_back(buf_with_index);
         if (curmsg->crlf) {
             lines.push_back("");
         }
